@@ -106,7 +106,8 @@ loadWorkbook <- function(file, password=NULL)
 #' @rdname Workbook
 saveWorkbook <- function(wb, file, password=NULL)
 {
-  jFile <- .jnew("java/io/File", file)
+  nfile <- normalizePath(file, mustWork = FALSE)
+  jFile <- .jnew("java/io/File", nfile)
   fh <- .jnew("java/io/FileOutputStream", jFile)
 
   # write the workbook to the file
@@ -129,7 +130,7 @@ saveWorkbook <- function(wb, file, password=NULL)
     opc$save(outputStream)
     opc$close()
 
-    fos <- .jnew("java/io/FileOutputStream", file)
+    fos <- .jnew("java/io/FileOutputStream", nfile)
     fs$writeFilesystem(fos)
     fos$close()
   }
