@@ -43,15 +43,6 @@
 
   set_java_tmp_dir(getOption("xlsx.tempdir", tempdir()))
 
-  # what's your java  version?  Need > 1.5.0.
-  jversion <- .jcall('java.lang.System','S','getProperty','java.version')
-
-  parse_version <- regexpr("[0-9]+\\.[0-9]+\\.[0-9]+", jversion)
-  clean_version <- substr(jversion, parse_version, attr(parse_version, "match.length"))
-  if (utils::compareVersion(clean_version,"1.5.0") < 0)
-    stop(paste("Your java version is ", jversion,
-                 ".  Need 1.5.0 or higher.", sep=""))
-
   wb <- createWorkbook()   # load/initialize jars here as it takes
   rm(wb)                   # a few seconds ...
 
